#
# This file is part of python sample package for the BROADWAY2 package.
#
# MIT License

# Copyright (c) 2013-2019 FibreCode GmbH <info@fibrecode.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

#
# enable text-file (csv) as input for sending raw Ethernt frames on multiple end-points
#
# Syntax: Name,TgtAddr,SrcAddr,EthType,Data


import os, sys
import csv
import binascii

from broadway2 import broadway_api, Broadway, FCAdapter, MultiRawSender

# Default Example requires 3x USB Adapters-Raw: Friendly Names set to 'silver', 'yellow' and 'orange'
# Sending is done for simple LLC-protocol to support wireshark decoding and passing switch-configs without VLAN enabled
# Adjust additional csv-files and use them as argument for different settings

DefaultCsvExample = [
"Name,TgtAddr,SrcAddr,EthType,Data",
"chip,FFFFFFFFFFFF,,0042,1234FC11000100112233445566778899AABBCCDD000200112233445566778899AABBCCDD000300112233445566778899AABBCCDD000400112233445566778899AABBCCDD",
"chip,FFFFFFFFFFFF,,0042,1234FC22000100112233445566778899AABBCCDD000200112233445566778899AABBCCDD000300112233445566778899AABBCCDD000400112233445566778899AABBCCDD",
"chap,FFFFFFFFFFFF,,0042,1234FC33000100112233445566778899AABBCCDD000200112233445566778899AABBCCDD000300112233445566778899AABBCCDD000400112233445566778899AABBCCDD"
]


def main(args):

    if len(args) > 1:
        csvFile = args[1]
    else:
        csvFile = os.path.join(os.path.split(args[0])[0], 'default.csv')

    multiTx = MultiRawSender()

    base = Broadway()

    if base.Count < 1:
        print('No Adapters found!')
        sys.exit(-1)

    for a in base.enumerate():
        if a.Features['Raw']:
            print('found {0} on {1} and added to list.'.format(a.FriendlyName, a.Inst))
            dev = base.open_raw_tx(a.Inst)

            multiTx.add(a, dev)

    if not os.path.exists(csvFile):
        print('{0} not found. Created some demo contents'.format(csvFile))
        f = open(csvFile, 'w', encoding='UTF-8')
        for line in DefaultCsvExample:
            f.write(line+"\n")
        f.close()

    try:
        f = open(csvFile, 'r', encoding='UTF-8')
    except:
        print('Error in input file {0}'.format(csvFile))
        return False

    res = multiTx.verify_csv(f)
    if res == 0:
        cnt = 0
        while multiTx.step(f):
            cnt += 1
        print('Sent out: {0}'.format(cnt))
    else:
        print('csv contains errors or does not match FrindlyNames-Setup {0}'.format(res))

    f.close()

    for dev in multiTx.enumerate():
        base.close(dev)



if __name__ == "__main__":
    main(sys.argv)
