#
# This file is part of python sample package for the BROADWAY2 package.
#
# MIT License

# Copyright (c) 2013-2019 FibreCode GmbH <info@fibrecode.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import sys
import time
import binascii
import struct

from broadway2 import Broadway, SpiAccess, SJAXAccess


def main(args):
    spiAdapter = []

    base = Broadway()

    aList = base.get_tool_adapters()    # only get FC401 SPI/SMI Tool Adapters

    print('Num Tool Adapters found: {0}'.format(len(aList)))
    print()


    # verify to have just one Tool-Adapter connected
    for a in aList:
        inst, friendlyName = a

        adapter = base.get_adapter(inst)
        
        dev = base.open_control(inst)

        adapter.connect(dev)

        spiAccess = SpiAccess(dev) # create spi adapter to get interface

        # configure correct mode:

        # protocol = 0: CPOL=0 CPHA=0
        # protocol = 1: CPOL=0 CPHA=1

        spiAccess.set_speed(1e6) # if longer cables1 are used 1MBit is better

        print('Probe SPI on: {0}/{1}'.format(inst, friendlyName))
        print('-'*60)
        for spiProtocol in range(0,2):

            spiAccess.set_protocol(spiProtocol)

            for cs in range(0,2):

                swAccess = SJAXAccess(spiAccess, cs)
        
                deviceId = swAccess.read_reg(0)
                
                print('Probing SPI: ProtocolId: {0} CS:{1}'.format(spiProtocol, cs))

                if deviceId == 0xAE00030E:
                    print('  -> Found: SJA1105QS')

                elif deviceId == 0xAF00030E:
                    print('  -> Found: SJA1105PR')
                
                elif deviceId == 0xB700030E:
                    print('  -> Found: SJA1110RevA')
                elif deviceId == 0xB700030F:
                    print('  -> Found: SJA1110RevC')
                else:
                    print('invalid or unknown device')
                print()
                
        
        print()
        base.close(dev)     # finaly close device


if __name__ == "__main__":
    main(sys.argv)

