#
# This file is part of python sample package for the BROADWAY2 package.
#
# MIT License

# Copyright (c) 2013-2019 FibreCode GmbH <info@fibrecode.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import sys
import time
import binascii
import struct

from broadway2 import Broadway, SpiAccess, SmiAccess, PhyAccess
from broadway2 import get_phy_access

# Please note:
# ------------------
# Use fc_control and rename FC401-Adapter connected to OM14500TJA1101 to "TJA1101-EVB"
# As broadway2-API supports multiple instances, multiple boards may be suffixed using -1, -2, ...

# Example how to control OM14500TJA1101 via FC401 adapter. Get full access to TJA1101 via SMI

ToolAdapterName = 'TJA1101-EVB'

def main(args):
    
    base = Broadway()

    tja1101Adapter = base.get_adapter_by_name(ToolAdapterName)
    # verify to have just one Tool-Adapter connected
    if tja1101Adapter != None:
        print('Use Tool-Adapter: {0} / {1}'.format(tja1101Adapter.SerialNumber, tja1101Adapter.FriendlyName))

        # get USB control device
        dev = base.open_control(tja1101Adapter.Inst)

        # connect adapter instance to this control device
        tja1101Adapter.connect(dev)

        phyAccess = get_phy_access(tja1101Adapter)

        print('PhyID: {0:04X}.{1:04X}'.format(phyAccess.read_reg(2), phyAccess.read_reg(3)))
        
        
        # close USB-Control device before exit
        base.close(dev)
    else:
        print('Tool Adapter NOT found! ', ToolAdapterName)



if __name__ == "__main__":
    main(sys.argv)



